pub fn installed_routine_names(proj_dirs: &ProjectDirs) -> Vec<String>Expand description
Sorted routine names that have at least one installed version directory.
pub fn installed_routine_names(proj_dirs: &ProjectDirs) -> Vec<String>Sorted routine names that have at least one installed version directory.